*********************
DHParser User's Guide
*********************

This user's guide explains how to use create, test and employ a domain
specific language with DHParser for encoding text or data in a Digital
Humanities Project.

Introduction
============

Most Digital Humanities projects or least most text-centered DH projects
involve in some way or other the entering and encoding of annotated text or
data into a computer. And the systems that scientists use for that purpose
consist of an input surface (or "redactation system") for entering the data, a
storage system to keep the data and a presentation system for providing the
data and possibly also functionality for working with the data to human or
machine receipients. A typical example of this type of system is Berlin'
Ediarum-System, which consists of an XML-Editor for entering data, an
XML-Database for storing the data and a web application for providing the data
to human readers or other web services via an application programming
interface (API). Ediarum is also typical, because like many DH-projects it
assumes an XML-based workflow.

